@@ -13,9 +13,7 @@
  * General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  */
 
 /* This file is shared between mutter (src/core/meta-xrandr-shared.h)
@@ -39,5 +37,5 @@ typedef enum {
 
 #define META_OUTPUT_STRUCT         "(uxiausauau@a{sv})"
 #define META_CRTC_STRUCT           "(uxiiiiiuau@a{sv})"
-#define META_MONITOR_MODE_STRUCT   "(uxuud)"
+#define META_MONITOR_MODE_STRUCT   "(uxuudu)"
 #endif
